<?php
/**
 * Welcome Page Class
 *
 * Shows a feature overview for the new version (major).
 *
*/

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * DecFirebase_Welcome_Page class.
 *
 */
class DecFirebase_Welcome_Page {

	private $plugin;

	/**
	 * __construct function.
	 *
	 * @access public
	 * @return void
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menus') );
		add_action( 'admin_head', array( $this, 'admin_head' ) );
		add_action( 'admin_init', array( $this, 'welcome'    ) );
	}

	/**
	 * Add admin menus/screens
	 *
	 * @access public
	 * @return void
	 */
	public function admin_menus() {
		$welcome_page_title = __( 'Welcome to DEC firebase plugin!', 'decfirebase' );
		$about = add_dashboard_page( $welcome_page_title, $welcome_page_title, 'manage_options', 'decfirebase-about', array( $this, 'about_screen' ) );
	}
	
	/**
	 * Add styles just for this page, and remove dashboard page links.
	 *
	 * @access public
	 * @return void
	 */
	public function admin_head() {
		?>
		<style type="text/css">
			/*<![CDATA[*/
			.wc-badge {
				padding-top: 150px;
				height: 52px;
				width: 185px;
				color: #9c5d90;
				font-weight: bold;
				font-size: 14px;
				text-align: center;
				text-shadow: 0 1px 0 rgba(255, 255, 255, 0.6);
				margin: 0 -5px;
			}

			.about-wrap .wc-badge {
				position: absolute;
				top: 0;
				right: 0;
			}
			/*]]>*/
		</style>
		<?php
	}

	/**
	 * Output the about screen.
	 *
	 * @access public
	 * @return void
	 */
	public function about_screen() {
		global $decfirebase;
		
		?>
		<div class="wrap about-wrap">
			<h1><?php echo __( 'Welcome to DEC firebase Plugin!', 'decfirebase' ); ?></h1>

			<div class="about-text decfirebase-about-text">
				<?php
					echo __( 'Thanks for installing! To make the plugin working, Please click the "setting" button bellow to set up the plugin.', 'decfirebase' );
				?>
			</div>

			<div class="wc-badge"><?php printf( __( 'Version %s' ), $decfirebase->version ); ?></div>

			<p class="decfirebase-actions">
				<a href="<?php echo admin_url('admin.php?page=decfirebase_setting'); ?>" class="button button-primary"><?php _e( 'Settings', 'decfirebase' ); ?></a>
			</p>
		</div>
		<?php
	}

	/**
	 * Sends user to the welcome page on first activation
	 */
	public function welcome() {

		// Bail if no activation redirect transient is set
	    if ( ! get_transient( '_decfirebase_activation_redirect' ) )
			return;

		// Delete the redirect transient
		delete_transient( '_decfirebase_activation_redirect' );

		// Bail if activating from network, or bulk, or within an iFrame
		if ( is_network_admin() || isset( $_GET['activate-multi'] ) || defined( 'IFRAME_REQUEST' ) )
			return;

		if ( ( isset( $_GET['action'] ) && 'upgrade-plugin' == $_GET['action'] ) && ( isset( $_GET['plugin'] ) && strstr( $_GET['plugin'], 'decfirebase.php' ) ) )
			return;

		wp_safe_redirect( admin_url( 'index.php?page=decfirebase-about' ) );
		exit;
	}
}

new DecFirebase_Welcome_Page();