<?php
/**
 * Admin Reports
 *
 * Functions used for displaying sales and customer reports in admin.
 *
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
function do_decfirebase_edit_user() {
	
	$notice_message = $warning_message = '';
	
	
	$key = isset($_GET['key']) ? sanitize_text_field($_GET['key']) : '';
	
	
	if(empty($key)) {
		echo '
		<div class="wrap decfirebase">
			<div class="notice notice-warning"> 
				<p><strong>'.__( 'The user does not exit, please go back and select another user!', 'decfirebase' ).'</strong></p>
			</div>

			<p class="decfirebase-actions">
				<a href="'.admin_url('admin.php?page=decfirebase').'" class="button button-primary">'.__( 'Firebase Users', 'decfirebase' ).'</a>
			</p>
		</div>';
		exit();
	}
	
	
	
	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	check_firebaseurl_setting($decfirebase_url, $decfirebase_secrets);
	
	
	$user_url = $decfirebase_url.'users/'.$key.'.json?auth='.$decfirebase_secrets;
	
	
	if ( ! empty( $_POST ) ) {
		$user_data['email']				= isset( $_POST['email'] ) ? sanitize_text_field($_POST['email']) : '';
		$user_data['firstName']			= isset( $_POST['firstName'] ) ? sanitize_text_field($_POST['firstName']) : '';
		$user_data['lastName']			= isset( $_POST['lastName'] ) ? sanitize_text_field($_POST['lastName']) : '';
		$user_data['churchPosition']	= isset( $_POST['churchPosition'] ) ? sanitize_text_field($_POST['churchPosition']) : '';
		$user_data['pastoralGroup']		= isset( $_POST['pastoralGroup'] ) ? sanitize_text_field($_POST['pastoralGroup']) : '';
		$user_data['pastoralRole']		= isset( $_POST['pastoralRole'] ) ? sanitize_text_field($_POST['pastoralRole']) : '';
		$user_data['pastoralZone']		= isset( $_POST['pastoralZone'] ) ? sanitize_text_field($_POST['pastoralZone']) : '';
		$user_data['shepherdPosition']	= isset( $_POST['shepherdPosition'] ) ? sanitize_text_field($_POST['shepherdPosition']) : '';
		$user_data['certifiedMember']	= isset($_POST['certifiedMember']) && $_POST['certifiedMember'] == '1' ? true : false;
		$user_data['fullTimeEmployee']	= isset($_POST['fullTimeEmployee']) && $_POST['fullTimeEmployee'] == '1' ? true : false;
		
		$user_data_result = decfirebase_update_data($user_url, json_encode($user_data));
		
		if(!$user_data_result) {
			$warning_message =  __('Something went wrong, please try again later.', 'decfirebase');
		} else {
			$notice_message =  __('Changes saved. <br><a href="'.admin_url('admin.php?page=decfirebase').'">← Back to Firebase Users</a>', 'decfirebase');
		}
	}
	
	$user_data = decfirebase_get_data($user_url);
	?>
	<div class="wrap decfirebase">
		<form method="post" id="mainform" action="" enctype="multipart/form-data">
			<?php wp_nonce_field( 'decfirebase-link', '_wpnonce', true, true ); ?>
			
			<h1>Edit firebase user</h1>
			
			<?php if(!empty($notice_message)): ?>
			<div class="notice notice-success is-dismissible"> 
				<p><strong><?php echo $notice_message; ?></strong></p>
				<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
			</div>
			<?php endif; ?>
			
			<?php if(!empty($warning_message)): ?>
			<div class="notice notice-warning is-dismissible"> 
				<p><strong><?php echo $warning_message; ?></strong></p>
				<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
			</div>
			<?php endif; ?>
			
			
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row"><label for="sundayServiceKids">Key</label></th>
						<td>
							<p class="description"><?php echo $key; ?></p>
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="email">Email</label></th>
						<td>
							<input name="email" type="text" id="email" value="<?php echo $user_data['email']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="firstName">firstName</label></th>
						<td>
							<input name="firstName" type="text" id="firstName" value="<?php echo $user_data['firstName']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="lastName">lastName</label></th>
						<td>
							<input name="lastName" type="text" id="lastName" value="<?php echo $user_data['lastName']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="churchPosition">churchPosition</label></th>
						<td>
							<input name="churchPosition" type="text" id="churchPosition" value="<?php echo $user_data['churchPosition']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="pastoralGroup">pastoralGroup</label></th>
						<td>
							<input name="pastoralGroup" type="text" id="pastoralGroup" value="<?php echo $user_data['pastoralGroup']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="pastoralRole">pastoralRole</label></th>
						<td>
							<input name="pastoralRole" type="text" id="pastoralRole" value="<?php echo $user_data['pastoralRole']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="pastoralZone">pastoralZone</label></th>
						<td>
							<input name="pastoralZone" type="text" id="pastoralZone" value="<?php echo $user_data['pastoralZone']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="shepherdPosition">shepherdPosition</label></th>
						<td>
							<input name="shepherdPosition" type="text" id="shepherdPosition" value="<?php echo $user_data['shepherdPosition']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="certifiedMember">certifiedMember</label></th>
						<td>
							<fieldset>
								<p>
									<label><input name="certifiedMember" type="radio" value="1" <?php echo $user_data['certifiedMember'] == 1 ? 'checked' : ''; ?>> Yes</label><br>
									<label><input name="certifiedMember" type="radio" value="0" <?php echo $user_data['certifiedMember'] != 1 ? 'checked' : ''; ?>> No</label>
								</p>
							</fieldset>
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="fullTimeEmployee">fullTimeEmployee</label></th>
						<td>
							<fieldset>
								<p>
									<label><input name="fullTimeEmployee" type="radio" value="1" <?php echo $user_data['fullTimeEmployee'] == 1 ? 'checked' : ''; ?>> Yes</label><br>
									<label><input name="fullTimeEmployee" type="radio" value="0" <?php echo $user_data['fullTimeEmployee'] != 1 ? 'checked' : ''; ?>> No</label>
								</p>
							</fieldset>
						</td>
					</tr>
				</tbody>
			</table>
			
			<p class="submit">
				<input name="save" class="button-primary" type="submit" value="<?php _e( 'Save changes', 'decfirebase' ); ?>" />
				<a href="<?php echo admin_url('admin.php?page=decfirebase'); ?>" class="button button-primary" style="margin-left: 10px;">Cancel</a>
			</p>
			
			<input name="key" type="hidden" value="<?php echo $key; ?>">
		</form>
	</div>
	
	<?php
}