<?php
/**
 * Admin Reports
 *
 * Functions used for displaying sales and customer reports in admin.
 *
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
function do_decfirebase_edit_user_notification() {
	
	$notice_message = $warning_message = '';
	
	
	$key = isset($_GET['key']) ? sanitize_text_field($_GET['key']) : '';
	
	
	if(empty($key)) {
		echo '
		<div class="wrap decfirebase">
			<div class="notice notice-warning"> 
				<p><strong>'.__( 'The user notification does not exit, please go back and select another notification!', 'decfirebase' ).'</strong></p>
			</div>

			<p class="decfirebase-actions">
				<a href="'.admin_url('admin.php?page=decfirebase_user_notification').'" class="button button-primary">'.__( 'Firebase User notifications', 'decfirebase' ).'</a>
			</p>
		</div>';
		exit();
	}
	
	
	
	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	check_firebaseurl_setting($decfirebase_url, $decfirebase_secrets);
	
	
	$user_notification_url = $decfirebase_url.'user_notifications/'.$key.'.json?auth='.$decfirebase_secrets;
	
	
	if ( ! empty( $_POST ) ) {
		$user_notification_data['title']	= isset( $_POST['title'] ) ? sanitize_text_field($_POST['title']) : '';
		$user_notification_data['url']		= isset( $_POST['url'] ) ? sanitize_text_field($_POST['url']) : '';
		$user_notification_data['content']	= isset( $_POST['content'] ) ? sanitize_text_field($_POST['content']) : '';
		
		$user_notification_data_result = decfirebase_update_data($user_notification_url, json_encode($user_notification_data));
		
		if(!$user_notification_data_result) {
			$warning_message =  __('Something went wrong, please try again later.', 'decfirebase');
		} else {
			$notice_message =  __('Changes saved. <br><a href="'.admin_url('admin.php?page=decfirebase_user_notification').'">← Back to Firebase User notifications</a>', 'decfirebase');
		}
	}
	
	$user_notification_data = decfirebase_get_data($user_notification_url);
	?>
	<div class="wrap decfirebase">
		<form method="post" id="mainform" action="" enctype="multipart/form-data">
			<?php wp_nonce_field( 'decfirebase-link', '_wpnonce', true, true ); ?>
			
			<h1>Edit firebase user notification</h1>
			
			<?php if(!empty($notice_message)): ?>
			<div class="notice notice-success is-dismissible"> 
				<p><strong><?php echo $notice_message; ?></strong></p>
				<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
			</div>
			<?php endif; ?>
			
			<?php if(!empty($warning_message)): ?>
			<div class="notice notice-warning is-dismissible"> 
				<p><strong><?php echo $warning_message; ?></strong></p>
				<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button>
			</div>
			<?php endif; ?>
			
			
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row"><label for="sundayServiceKids">Key</label></th>
						<td>
							<p class="description"><?php echo $key; ?></p>
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="title">Title</label></th>
						<td>
							<input name="title" type="text" id="title" value="<?php echo $user_notification_data['title']; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="url">URL</label></th>
						<td>
							<input name="url" type="url" id="url" value="<?php echo isset($user_notification_data['url']) ? $user_notification_data['url']: ''; ?>" class="regular-text">
						</td>
					</tr>
					<tr>
						<th scope="row"><label for="content">content</label></th>
						<td>
							<textarea name="content" id="content" class="large-text code" rows="3"><?php echo $user_notification_data['content']; ?></textarea>
						</td>
					</tr>
					
					
				</tbody>
			</table>
			
			<p class="submit">
				<input name="save" class="button-primary" type="submit" value="<?php _e( 'Save changes', 'decfirebase' ); ?>" />
				<a href="<?php echo admin_url('admin.php?page=decfirebase_user_notification'); ?>" class="button button-primary" style="margin-left: 10px;">Cancel</a>
			</p>
			
			<input name="key" type="hidden" value="<?php echo $key; ?>">
		</form>
	</div>
	
	<?php
}