<?php
/**
 * Admin Users
 *
 * Functions used for displaying and managing all the user account in admin.
 *
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
function do_decfirebase_user_notification() {
	global $decfirebase;
	
	
	$notice_message = $warning_message = '';
	
	
	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	check_firebaseurl_setting($decfirebase_url, $decfirebase_secrets);
	
	
	//Pagination
	$uid = isset($_GET['uid']) && !empty($_GET['uid']) ? sanitize_text_field($_GET['uid']) : '';
	$last_user_key = '';
	
	
	$first_page_data = decfirebase_get_user_notifications($uid, $decfirebase->page_size);
?>
	<div class="wrap decfirebase">
		<h1>DEC Firebase User notifications</h1>
		
		<div class="tablenav top">
			<div class="alignleft bulkactions">
				<form method="get">
					<label for="bulk-action-selector-top" class="screen-reader-text">Search by UID</label>
					<span>UID: </span>
					<input type="text" name="uid" value="<?php echo $uid; ?>">
					<input type="submit" class="button action" value="Search">
					
					<input type="hidden" name="page" value="decfirebase_user_notification">
				</form>
			</div>
			<br class="clear">
		</div>

		<table class="wp-list-table widefat fixed striped table-view-list posts">
			<thead>
				<tr>
					<th scope="col" class="manage-column">ID</th>
					<th scope="col" class="manage-column">uid</th>
					<th scope="col" class="manage-column">title</th>
					<th scope="col" class="manage-column">content</th>
					<th scope="col" class="manage-column">date</th>
					<th scope="col" class="manage-column">readDate</th>
					<th scope="col" class="manage-column">URL</th>
					<th scope="col" class="manage-column">Action</th>
				</tr>
			</thead>

			<tbody id="the-list">
				<?php foreach($first_page_data as $key => $val): ?>
				<tr>
					<td><?php echo $val['notificationID']; ?></td>
					<td><?php echo $val['uid']; ?></td>
					<td><?php echo $val['title']; ?></td>
					<td><?php echo $val['content']; ?></td>
					<td><?php echo $val['date']; ?></td>
					<td><?php echo $val['readDate']; ?></td>
					<td><?php echo isset($val['url']) ? $val['url'] : ''; ?></td>
					<td class="decfirebase-links">
						<span class="edit"><a href="<?php echo admin_url('admin.php?page=decfirebase_edit_notification&key='.$val['uid'].'/'.$key); ?>">Edit</a> | </span>
						<span class="trash"><a class="delete-notification" data-key="<?php echo $val['uid'].'/'.$key; ?>" href="<?php echo admin_url('admin.php?page=decfirebase_delete_notification&key='.$val['uid'].'/'.$key); ?>">Delete</a></span>
					</td>
				</tr>
				<?php
					
					if(empty($uid)) {
						$last_user_key = $val['uid'];
					} else {
						$last_user_key = $val['notificationID'];
					}
				endforeach;
				?>
			</tbody>
		</table>
		
		<div class="tablenav bottom">
			<div class="actions bulkactions">
			
				<button id="load_more" class="button action">Load more...</button>
				
				<div id="loading_notice" class="decfirebase-message" style="display: none;">
					<p><img src="<?php echo $decfirebase->plugin_url(); ?>/assets/image/loading.gif" /> Loading...</p>
				</div>
				
				<div id="no_data_notice" class="decfirebase-message" style="display: none;">
					<p>No more data...</p>
				</div>
			</div>
			<br class="clear">
		</div>
	</div>
	
	<script>
	jQuery(document).ready(function() {
		var last_user_key = "<?php echo $last_user_key; ?>";
		var admin_url1 = "<?php echo admin_url('admin.php?page=decfirebase_edit_notification&key='); ?>";
		var admin_url2 = "<?php echo admin_url('admin.php?page=decfirebase_delete_notification&key='); ?>";
		
		jQuery("#load_more").click(function() {
			
			jQuery("#load_more").hide();
			jQuery("#loading_notice").show();
			
			jQuery.getJSON("/?action=decfirebase_user_notification&uid=<?php echo $uid; ?>&page_size=<?php echo $decfirebase->page_size; ?>&start_at=" + last_user_key, function( data ) {
				jQuery.each( data, function( key, val) {
					var new_tr = jQuery(
					"<tr>"+
						"<td>" + val.notificationID + "</td>"+
						"<td>" + val.uid + "</td>"+
						"<td>" + val.title + "</td>"+
						"<td>" + val.content + "</td>"+
						"<td>" + val.date + "</td>"+
						"<td>" + val.readDate + "</td>"+
						"<td>" + (val.url !== undefined ? val.url : '') + "</td>"+
						"<td class=\"decfirebase-links\">" +
							"<span class=\"edit\"><a href=\"" + admin_url1 + val.notificationID + "\">Edit</a> | </span>"+
							"<span class=\"trash\"><a class=\"delete-notification\" data-key=\"" + val.uid + "/" + val.notificationID + "\" href=\"" + admin_url2 + val.uid + "/" + val.notificationID  + "\">Delete</a></span>"+
						"</td>"+
					"</tr>" ).hide();
					
					jQuery("#the-list").append(new_tr);
					new_tr.show();
					
					<?php
					if(empty($uid)) {
						echo "last_user_key = val.uid;";
					} else {
						echo "last_user_key = val.notificationID;";
					}
					?>
					
				});
				
				
				
				jQuery(".delete-notification").click(function(e) {
					e.preventDefault();
					
					if(confirm("Are you sure to delete this notification?")) {
						var this_obj = jQuery(this);
						var key = this_obj.attr("data-key");
						
						jQuery.get("/?action=decfirebase_delete_user_notification&key=" + key, function( data ) {
							if(data == 'OK') {
								alert("Notification deleted");
								
								this_obj.closest("tr").css("background", "#f1c4c4").fadeOut(500).fadeIn(500).slideUp(300);
							} else {
								alert("Something went wrong, please try it again later!");
							}
						});
					}
				});
				
				
				
				jQuery("#loading_notice").hide();
				
				if(data.length <= 0) {
					jQuery("#no_data_notice").show();
				} else {
					jQuery("#load_more").show();
				}
			});
		});
		
		
		jQuery(".delete-notification").click(function(e) {
            e.preventDefault();
            
			if(confirm("Are you sure to delete this notification?")) {
				var this_obj = jQuery(this);
				var key = this_obj.attr("data-key");
				
				jQuery.get("/?action=decfirebase_delete_user_notification&key=" + key, function( data ) {
					if(data == 'OK') {
						alert("Notification deleted");
						
						this_obj.closest("tr").css("background", "#f1c4c4").fadeOut(500).fadeIn(500).slideUp(300);
					} else {
						alert("Something went wrong, please try it again later!");
					}
				});
			}
        });
	});
	</script>
<?php
	
}