<?php
/**
 * Plugin Name: DEC firebase plugin
 * Plugin URI: https://dec4u.org/
 * Description: Dec firebase plugin
 * Version: 1.0.4
 * Author: DEC IT Team
 * Author URI: https://dec4u.org
 * Requires at least: 5.0
 * Tested up to: 5.6
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly


if ( ! class_exists( 'DecFirebase' ) ) {
	class DecFirebase {
		/**
		 * @var string
		 */
		public $version = '1.0.4';
		
		/**
		 * @var int
		 */
		public $page_size = 10;
		
		/**
		 * @var string
		 */
		public $plugin_url;

		/**
		 * @var string
		 */
		public $plugin_path;
		
		/**
		 * Constructor.
		 *
		 * @access public
		 * @return void
		 */
		public function __construct() {
			// Installation
			register_activation_hook( __FILE__, array( $this, 'activate' ) );
			register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );
			
			// Include required files
			$this->includes();
			
			// Hooks// Hooks
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'action_links' ) );
			add_action( 'init', array( $this, 'init' ), 0 );
			
			// Loaded action
			do_action( 'decfirebase_loaded' );
		}
		
		/**
		 * activate function.
		 *
		 * @access public
		 * @return void
		 */
		public function activate() {
			set_transient( '_decfirebase_activation_redirect', 1, 5 * 60 * 60 );
			
			return true;
		}
		
		public function deactivate() {
			return true;
		}
		
		/**
		 * action_links function.
		 *
		 * @access public
		 * @param mixed $links
		 * @return void
		 */
		public function action_links( $links ) {

			$plugin_links = array(
				'<a href="' . admin_url( 'admin.php?page=decfirebase_setting' ) . '">' . __( 'Settings', 'decfirebase' ) . '</a>',
				'<a href="https://dec4u.org/" target="_blank">' . __( 'About us', 'decfirebase' ) . '</a>',
				'<a href="https://dec4u.org/609-2/" target="_blank">' . __( 'Support', 'decfirebase' ) . '</a>',
			);

			return array_merge( $plugin_links, $links );
		}
		
		/**
		 * Include required core files used in admin and on the frontend.
		 *
		 * @access public
		 * @return void
		 */
		function includes() {
			include_once( 'functions.php' );
			include_once( 'hooks.php' );
			
			if ( is_admin() ) {
				include_once( 'admin/admin-init.php' );			// Admin section
				include_once( 'admin/admin-function.php' );			// Admin section
			}
		}
		
		/**
		 * Init decfirebase when WordPress Initialises.
		 *
		 * @access public
		 * @return void
		 */
		public function init() {
			// Init action
			do_action( 'decfirebase_init' );
		}
		
		/** Helper functions ******************************************************/

		/**
		 * Get the plugin url.
		 *
		 * @access public
		 * @return string
		 */
		public function plugin_url() {
			if ( $this->plugin_url ) return $this->plugin_url;
			return $this->plugin_url = untrailingslashit( plugins_url( '/', __FILE__ ) );
		}


		/**
		 * Get the plugin path.
		 *
		 * @access public
		 * @return string
		 */
		public function plugin_path() {
			if ( $this->plugin_path ) return $this->plugin_path;

			return $this->plugin_path = untrailingslashit( plugin_dir_path( __FILE__ ) );
		}


		/**
		 * Get Ajax URL.
		 *
		 * @access public
		 * @return string
		 */
		public function ajax_url() {
			return admin_url( 'admin-ajax.php', 'relative' );
		}


		/**
		 * Return the Dec Firebase API URL for a given request
		 *
		 * @access public
		 * @param mixed $request
		 * @param mixed $ssl (default: null)
		 * @return string
		 */
		public function api_request_url( $request, $ssl = null ) {
			if ( is_null( $ssl ) ) {
				$scheme = parse_url( get_option( 'home' ), PHP_URL_SCHEME );
			} elseif ( $ssl ) {
				$scheme = 'https';
			} else {
				$scheme = 'http';
			}

			return esc_url_raw( trailingslashit( home_url( '/decfirebase-api/' . $request, $scheme ) ) );
		}
	}

	/**
	 * Init decfirebase class
	 */
	$GLOBALS['decfirebase'] = new DecFirebase();

}