<?php
/**
 * DEC firebase plugin Functions
 *
 * Hooked-in functions for related events on the front-end.
 *
 */

function decfirebase_ajax_get_users() {
	global $decfirebase;
	
	if ((isset($_GET['action']) && $_GET['action'] == 'decfirebase_user' )) {
		
		//Get parameters.
		$page_size = isset($_GET['page_size']) && !empty($_GET['page_size']) ? sanitize_text_field($_GET['page_size']) : $decfirebase->page_size;
		$start_at = isset($_GET['start_at']) ? sanitize_text_field($_GET['start_at']) : '';
		
		
		$user_data = decfirebase_get_user_data($page_size, $start_at);
		
		
		echo json_encode($user_data);
		exit();
	}
}


function decfirebase_ajax_get_user_notifications() {
	global $decfirebase;
	
	if ((isset($_GET['action']) && $_GET['action'] == 'decfirebase_user_notification' )) {
		
		//Get parameters.
		$uid = isset($_GET['uid']) && !empty($_GET['uid']) ? sanitize_text_field($_GET['uid']) : '';
		$page_size = isset($_GET['page_size']) && !empty($_GET['page_size']) ? sanitize_text_field($_GET['page_size']) : $decfirebase->page_size;
		$start_at = isset($_GET['start_at']) ? sanitize_text_field($_GET['start_at']) : '';
		
		
		$user_data = decfirebase_get_user_notifications($uid, $page_size, $start_at);
		
		
		echo json_encode($user_data);
		exit();
	}
}



function decfirebase_ajax_delete_user_notification() {
	global $decfirebase;
	
	if ((isset($_GET['action']) && $_GET['action'] == 'decfirebase_delete_user_notification' )) {
		
		//Get parameters.
		$key = isset($_GET['key']) && !empty($_GET['key']) ? sanitize_text_field($_GET['key']) : '';
		
		$user_data = decfirebase_delete_user_notification($key);
		
		
		echo $user_data;
		exit();
	}
}



//Get use data from firebase realtime database.
function decfirebase_get_user_data($page_size = 20, $start_at = '') {

	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	
	if(empty($decfirebase_url) || empty($decfirebase_secrets)) {
		$user_data =array();
	} else {
		$remove_first = false;
		if(!empty($start_at) && !empty($page_size)) {
			$remove_first = true;
			$page_size = $page_size + 1;
		}
		
		
		//Get API URL Ready.
		$user_url = $decfirebase_url."users/.json?orderBy=%22\$key%22&startAt=%22{$start_at}%22&limitToFirst={$page_size}&auth={$decfirebase_secrets}";
		
		
		//Get data from firebase.
		$user_data = decfirebase_get_data($user_url);
		
		//Remove first element if necessary.
		if($remove_first) {
			array_shift($user_data);
		}
		
		
		//Double check result.
		if(empty($user_data)) {
			$user_data = array();
		}
	}
	
	
	return $user_data;
}


//Get use notification data from firebase realtime database.
function decfirebase_get_user_notifications($uid = '', $page_size = 20, $start_at = '') {

	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	
	if(empty($decfirebase_url) || empty($decfirebase_secrets)) {
		$user_notification_data =array();
	} else {
		$remove_first = false;
		if(!empty($start_at) && !empty($page_size)) {
			$remove_first = true;
			$page_size = $page_size + 1;
		}
		
		
		//Get API URL Ready.
		$user_notification_url = $decfirebase_url."user_notifications/".(!empty($uid) ? $uid.'/' : '').".json?orderBy=%22\$key%22&startAt=%22{$start_at}%22&limitToFirst={$page_size}&auth={$decfirebase_secrets}";
		
		
		//Get data from firebase.
		$user_notification_data = decfirebase_get_data($user_notification_url);
		
		
		//Remove first element if necessary.
		if($remove_first) {
			array_shift($user_notification_data);
		}
		
		
		//Double check result.
		if(empty($user_notification_data)) {
			$user_notification_data = array();
		}
		
		
		//Deal with data
		if(empty($uid)) {
			$user_notification_data_tmp = $user_notification_data;
			$user_notification_data = array();
			
			foreach($user_notification_data_tmp as $uid => $val1) {
				foreach($val1 as $key => $val2) {
					$val2['uid'] = $uid;
					$user_notification_data[$key] = $val2;
				}
			}
		} else {
			foreach($user_notification_data as $key => $val) {
				$user_notification_data[$key]['uid'] = $uid;
			}
		}
		
	}
	
	
	return $user_notification_data;
}


//Delete use notification data from firebase realtime database.
function decfirebase_delete_user_notification($key) {

	$decfirebase_url = get_option('decfirebase_url');
	$decfirebase_secrets = get_option('decfirebase_secrets');
	
	if(empty($decfirebase_url) || empty($decfirebase_secrets)) {
		$result ='';
	} else {
		if(empty($key)) {
			$result ='';
		} else {
			//Get API URL Ready.
			$user_notification_delete_url = $decfirebase_url."user_notifications/{$key}/.json?auth={$decfirebase_secrets}";
			
			if(decfirebase_delete_data($user_notification_delete_url)) {
				$result = 'OK';
			} else {
				$result = 'NG';
			}
		}
	}
	
	
	return $result;
}



//Functino to get and update data to Firebase Realtime Database.
function decfirebase_get_data($url) {
	if(empty($url)) {
		return array();
	}
	
	$response = wp_remote_get($url);
	$result = wp_remote_retrieve_body($response);
	$http_code = wp_remote_retrieve_response_code( $response );
	
	if($http_code == 200) {
		return empty($result) ? array() : json_decode($result, true);
	} else {
		return array();
	}
}

function decfirebase_update_data($url, $data) {
	if(empty($url)) {
		return false;
	}
	
	$args = array(
		'body'			=> $data,
		'method'		=> 'PATCH',
		'timeout'		=> '5',
		'redirection'	=> '5',
		'httpversion'	=> '1.0',
		'blocking'		=> true,
		'headers'		=> array(),
		'cookies'		=> array(),
	);

	$response = wp_remote_get($url, $args);
	$result = wp_remote_retrieve_body($response);
	$http_code = wp_remote_retrieve_response_code( $response );
	
	if($http_code == 200) {
		return true;
	} else {
		return false;
	}
}


function decfirebase_add_data($url, $data) {
	if(empty($url)) {
		return false;
	}
	
	$args = array(
		'body'			=> $data,
		'method'		=> 'POST',
		'timeout'		=> '5',
		'redirection'	=> '5',
		'httpversion'	=> '1.0',
		'blocking'		=> true,
		'headers'		=> array(),
		'cookies'		=> array(),
	);

	$response = wp_remote_get($url, $args);
	$result = wp_remote_retrieve_body($response);
	$http_code = wp_remote_retrieve_response_code( $response );
	
	
	if($http_code == 200) {
		$result_array = json_decode($result, true);
		return isset($result_array['name']) ? $result_array['name'] : false;
	} else {
		return false;
	}
}


function decfirebase_delete_data($url) {
	if(empty($url)) {
		return false;
	}
	
	$args = array(
		'body'			=> '',
		'method'		=> 'DELETE',
		'timeout'		=> '5',
		'redirection'	=> '5',
		'httpversion'	=> '1.0',
		'blocking'		=> true,
		'headers'		=> array(),
		'cookies'		=> array(),
	);

	$response = wp_remote_get($url, $args);
	$result = wp_remote_retrieve_body($response);
	$http_code = wp_remote_retrieve_response_code( $response );
	
	
	if($http_code == 200) {
		return true;
	} else {
		return false;
	}
}


function decfirebase_display_user_field($data, $depth = -1) {
	$depth ++;
	
	if(is_array($data)) {
		foreach($data as $key => $val) {
			for($i = 0; $i < $depth; $i++) {
				if($i == 0) {
					echo '┕—';
				} else{
					echo '——';
				}
			}
			echo $key.': ';
			
			if(is_array($val)) {
				echo '<br>';
				decfirebase_display_user_field($val, $depth);
			} else {
				echo $val.'<br>';
			}
		}
	} else {
		echo $data;
	}
}



//For debug
if(!function_exists('pr')) {
	function pr($val) {
		echo '<pre>';
		if(empty($val)) {
			var_dump($val);
		} else {
			print_r($val);
		}
		echo '</pre>';
		echo '<hr/>';
	}
}



